@@ -19,6 +19,8 @@ VAT_NUMBERS = [
     ('AL', 'AA9999999L', False),
     ('AL', 'KA9999999L', False),
     ('AL', 'K999999991', False),
+    ('AR', '00000000000', True),
+    ('AR', '00000000001', False),
     ('BE', '0123456749', True),
     ('BE', '0897290877', True),
     ('BE', '01234567490', False),
@@ -43,7 +45,7 @@ VAT_NUMBERS = [
     ('CO', '900127933', False),
     ('CO', 'A001279338', False),
     ('CO', '9001279320', True),
-    ('CY', '12345678F', True),
+    ('CY', '23456789U', True),
     ('CY', '2345678F', False),
     ('CY', 'A2345678F', False),
     ('CY', '12345678A', False),
@@ -126,16 +128,16 @@ VAT_NUMBERS = [
     ('ES', '1A345678Z', False),
     ('ES', '12345678A', False),
     ('FI', '12345671', True),
-    ('FR', '32123456789', True),
-    ('FR', '2H123456789', True),
+    ('FR', '11123456782', True),
+    ('FR', '0L123456782', True),
     ('GB', 'GD123', True),
     ('GB', 'GD888812326', True),
     ('GB', 'HA567', True),
     ('GB', 'HA888856782', True),
     ('GB', '123456782', True),
-    ('GB', '1234567823', True),
-    ('GB', '001123456782', True),
-    ('GB', '0011234567823', True),
+    ('GB', '102675046', True),
+    ('GB', '100190874', True),
+    ('GB', '003232345', True),
     ('GB', '242338087388', True),
     ('GR', '12345670', True),
     ('GR', '123456783', True),
@@ -146,11 +148,12 @@ VAT_NUMBERS = [
     ('IE', '7A12345J', True),
     ('IE', '1234567T', True),
     ('IT', '12345670017', True),
+    ('IT', '00118439991', True),
     ('LT', '123456715', True),
     ('LT', '123456789011', True),
     ('LU', '12345613', True),
     ('LV', '41234567891', True),
-    ('LV', '15066312345', True),
+    ('LV', '15066312341', True),
     ('MT', '12345634', True),
     ('NL', '123456782B90', True),
     ('PL', '1234567883', True),
@@ -161,14 +164,13 @@ VAT_NUMBERS = [
     ('RU', '5505035011', True),
     ('RU', '550501929014', True),
     ('SE', '123456789701', True),
+    ('SE', '556728341001', True),
     ('SI', '12345679', True),
-    ('SK', '0012345675', True),
-    ('SK', '0012345678', True),
-    ('SK', '531231123', True),
-    ('SK', '6306151234', True),
     ('SK', '2021853504', True),
+    ('SK', '4020246659', True),
     ('SM', '12345', True),
     ('UA', '12345678', True),
+    ('', '12456789', False),
 ]
 
 VIES_NUMBERS = [
@@ -187,7 +189,7 @@ class VatNumberTest(unittest.TestCase):
         '''
         for code, number, result in VAT_NUMBERS:
             if result:
-                test = self.assert_
+                test = self.assertTrue
             else:
                 test = self.assertFalse
             test(vatnumber.check_vat(code + number), code + number)
